@@ -402,10 +402,29 @@ Insertion <- function(...) {
     out <- GenericConstructor("Insertion")(..., data = data)
 
     # ensure that args is a list, even if it is a single element
-    if (!is.null(out$args) && length(out$args) == 1) {
+    if (is.null(out$args)) {
+        out$args <- NULL
+    } else if (length(out$args) == 1) {
         out$args <- as.list(out$args)
     }
 
+    # ensure that kwargs is missing if empty instead of NULL and is a list,
+    # even if it is a single element
+    # Note this is okay because all current kwargs are supposed to be lists
+    # but could cause problems if that changes
+    if (length(out$kwargs) == 0) {
+        out$kwargs <- NULL
+    } else {
+        for (kw in names(out$kwargs)) {
+            if (is.null(out$kwargs[[kw]])) {
+                out$kwargs[[kw]] <- NULL
+            }
+            else if (length(out$kwargs[[kw]]) == 1) {
+                out$kwargs[[kw]] <- as.list(out$kwargs[[kw]])
+            }
+        }
+    }
+
     return(out)
 }
 
