@@ -165,6 +165,10 @@ setGeneric("anchor<-", function(x, value) standardGeneric("anchor<-"))
 setGeneric("arguments", function(x, ...) standardGeneric("arguments"))
 #' @rdname Insertions
 setGeneric("arguments<-", function(x, value) standardGeneric("arguments<-"))
+# not exported
+setGeneric("kwarguments", function(x, ...) standardGeneric("kwarguments"))
+#' @rdname Insertions
+setGeneric("kwarguments<-", function(x, value) standardGeneric("kwarguments<-"))
 #' @rdname Insertions
 setGeneric("func", function(x) standardGeneric("func"))
 #' @rdname Insertions
